clients

package
v0.0.0-...-3528491 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 24, 2026 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockKubernetesClient

type MockKubernetesClient struct {
	mock.Mock
}

MockKubernetesClient is an autogenerated mock type for the KubernetesClient type

func NewMockKubernetesClient

func NewMockKubernetesClient(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockKubernetesClient

NewMockKubernetesClient creates a new instance of MockKubernetesClient. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockKubernetesClient) EXPECT

func (*MockKubernetesClient) GetDeployment

func (_mock *MockKubernetesClient) GetDeployment(ctx context.Context, namespacedName types.NamespacedName) (*v1.Deployment, error)

GetDeployment provides a mock function for the type MockKubernetesClient

func (*MockKubernetesClient) ListDeployments

func (_mock *MockKubernetesClient) ListDeployments(ctx context.Context, labelSelector labels.Selector) (*v1.DeploymentList, error)

ListDeployments provides a mock function for the type MockKubernetesClient

func (*MockKubernetesClient) ListPods

func (_mock *MockKubernetesClient) ListPods(ctx context.Context, labelSelector labels.Selector) (*v10.PodList, error)

ListPods provides a mock function for the type MockKubernetesClient

func (*MockKubernetesClient) UpdatePod

func (_mock *MockKubernetesClient) UpdatePod(ctx context.Context, pod v10.Pod) error

UpdatePod provides a mock function for the type MockKubernetesClient

type MockKubernetesClient_Expecter

type MockKubernetesClient_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockKubernetesClient_Expecter) GetDeployment

func (_e *MockKubernetesClient_Expecter) GetDeployment(ctx interface{}, namespacedName interface{}) *MockKubernetesClient_GetDeployment_Call

GetDeployment is a helper method to define mock.On call

  • ctx context.Context
  • namespacedName types.NamespacedName

func (*MockKubernetesClient_Expecter) ListDeployments

func (_e *MockKubernetesClient_Expecter) ListDeployments(ctx interface{}, labelSelector interface{}) *MockKubernetesClient_ListDeployments_Call

ListDeployments is a helper method to define mock.On call

  • ctx context.Context
  • labelSelector labels.Selector

func (*MockKubernetesClient_Expecter) ListPods

func (_e *MockKubernetesClient_Expecter) ListPods(ctx interface{}, labelSelector interface{}) *MockKubernetesClient_ListPods_Call

ListPods is a helper method to define mock.On call

  • ctx context.Context
  • labelSelector labels.Selector

func (*MockKubernetesClient_Expecter) UpdatePod

func (_e *MockKubernetesClient_Expecter) UpdatePod(ctx interface{}, pod interface{}) *MockKubernetesClient_UpdatePod_Call

UpdatePod is a helper method to define mock.On call

  • ctx context.Context
  • pod v10.Pod

type MockKubernetesClient_GetDeployment_Call

type MockKubernetesClient_GetDeployment_Call struct {
	*mock.Call
}

MockKubernetesClient_GetDeployment_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetDeployment'

func (*MockKubernetesClient_GetDeployment_Call) Return

func (*MockKubernetesClient_GetDeployment_Call) Run

func (*MockKubernetesClient_GetDeployment_Call) RunAndReturn

func (_c *MockKubernetesClient_GetDeployment_Call) RunAndReturn(run func(ctx context.Context, namespacedName types.NamespacedName) (*v1.Deployment, error)) *MockKubernetesClient_GetDeployment_Call

type MockKubernetesClient_ListDeployments_Call

type MockKubernetesClient_ListDeployments_Call struct {
	*mock.Call
}

MockKubernetesClient_ListDeployments_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'ListDeployments'

func (*MockKubernetesClient_ListDeployments_Call) Return

func (_c *MockKubernetesClient_ListDeployments_Call) Return(deploymentList *v1.DeploymentList, err error) *MockKubernetesClient_ListDeployments_Call

func (*MockKubernetesClient_ListDeployments_Call) Run

func (*MockKubernetesClient_ListDeployments_Call) RunAndReturn

func (_c *MockKubernetesClient_ListDeployments_Call) RunAndReturn(run func(ctx context.Context, labelSelector labels.Selector) (*v1.DeploymentList, error)) *MockKubernetesClient_ListDeployments_Call

type MockKubernetesClient_ListPods_Call

type MockKubernetesClient_ListPods_Call struct {
	*mock.Call
}

MockKubernetesClient_ListPods_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'ListPods'

func (*MockKubernetesClient_ListPods_Call) Return

func (*MockKubernetesClient_ListPods_Call) Run

func (*MockKubernetesClient_ListPods_Call) RunAndReturn

type MockKubernetesClient_UpdatePod_Call

type MockKubernetesClient_UpdatePod_Call struct {
	*mock.Call
}

MockKubernetesClient_UpdatePod_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'UpdatePod'

func (*MockKubernetesClient_UpdatePod_Call) Return

func (*MockKubernetesClient_UpdatePod_Call) Run

func (*MockKubernetesClient_UpdatePod_Call) RunAndReturn

Jump to